%global pypi_name mailman
%global bzr 7220

# The user and group Mailman will run as, same values as in the mailman 2 RPM
%global mmuser       mailman
%global mmuserid     41
%global mmgroup      mailman
%global mmgroupid    41


Name:           mailman3
Version:        3.0.0
Release:        0.6.bzr%{bzr}%{?dist}
Summary:        The GNU mailing list manager

License:        GPLv3
URL:            http://www.list.org
#Source0:        http://pypi.python.org/packages/source/m/%{pypi_name}/%{pypi_name}-%{version}b3.tar.gz
Source0:        mailman-%{version}-bzr%{bzr}.tar.gz
Source1:        mailman3.cfg
Source2:        mailman3-tmpfiles.conf
Source3:        mailman3.service
Source4:        mailman3.logrotate

# doctest hardcodes the exec path
Patch0:         mailman3-hooks-uselayout.patch
# https://bugs.launchpad.net/mailman/+bug/1130957
Patch2:         mailman3-bug1130957.patch
# https://bugs.launchpad.net/mailman/+bug/1158721
Patch3:         mailman3-notextpart.patch
# https://bugs.launchpad.net/mailman/+bug/1130696
Patch4:         mailman3-nosender.patch
# https://bugs.launchpad.net/mailman/+bug/1170347
Patch5:         mailman3-digestunicode.patch
# This test blocks the test suite under mock, it's signal-related, don't know
# why exactly (yet)
Patch6:         mailman3-failingtest.patch
# Only used to get the tests to pass (buildroot-related)
Patch7:         mailman3-fixtests.patch

BuildArch:      noarch

BuildRequires:  python-devel >= 2.7

Requires:       python >= 2.7
Requires:       python-flufl.bounce
Requires:       python-enum34
Requires:       python-flufl.i18n
Requires:       python-flufl.lock
Requires:       python-httplib2
Requires:       python-lazr.config
Requires:       python-lazr.smtptest
Requires:       python-mock
Requires:       python-restish
Requires:       python-storm
Requires:       python-zope-component
Requires:       python-zope-configuration
Requires:       python-zope-event
Requires:       python-zope-interface
Requires:       python-nose2
# Versionned dep on python-passlib, or else it fails with AttributeError in
# mailman/utilities/passwords.py", line 43: 'CryptContext' has no attribute 'from_string'
Requires:       python-passlib >= 1.6.0

# To run the test suite:
BuildRequires:  python-nose2
BuildRequires:  python-flufl.bounce
BuildRequires:  python-enum34
BuildRequires:  python-flufl.i18n
BuildRequires:  python-flufl.lock
BuildRequires:  python-httplib2
BuildRequires:  python-lazr.config
BuildRequires:  python-lazr.smtptest
BuildRequires:  python-mock
BuildRequires:  python-restish
BuildRequires:  python-storm
BuildRequires:  python-zope-component
BuildRequires:  python-zope-configuration
BuildRequires:  python-zope-event
BuildRequires:  python-zope-interface
BuildRequires:  python-passlib >= 1.6.0

# Scriptlets
Requires(pre):    shadow-utils
Requires(post):   systemd
Requires(preun):  systemd
Requires(postun): systemd
BuildRequires:    systemd


%description
This is GNU Mailman, a mailing list management system distributed under the
terms of the GNU General Public License (GPL) version 3 or later.  The name of
this software is spelled 'Mailman' with a leading capital 'M' but with a lower
case second `m'.  Any other spelling is incorrect.


%prep
#%%setup -q -n %{pypi_name}-%{version}b3
%setup -q -n mailman
%patch0 -p0 -b .hooks-uselayout
%patch2 -p0 -b .bug1130957
%patch3 -p0 -b .notextpart
%patch4 -p0 -b .nosender
%patch5 -p0 -b .digestunicode
%patch6 -p0 -b .failingtest
# Remove bundled egg-info
rm -rf src/%{pypi_name}.egg-info
# Use a distribute version compatible with F18
sed -i -e "s/0.6.32/0.6.28/" distribute_setup.py


%build
%{__python} setup.py build


%install
rm -rf %{buildroot}
%{__python} setup.py install -O1 --skip-build --root %{buildroot}

# move scripts away from _bindir to avoid conflicts
mkdir -p %{buildroot}%{_libexecdir}/%{name}
mv %{buildroot}%{_bindir}/* %{buildroot}%{_libexecdir}/%{name}/
ln -s %{_libexecdir}/%{name}/mailman %{buildroot}%{_bindir}/%{name}

# service files
install -D -m 0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/mailman.cfg
install -D -m 0644 %{SOURCE2} %{buildroot}%{_prefix}/lib/tmpfiles.d/%{name}.conf
install -D -m 0644 %{SOURCE3} %{buildroot}%{_prefix}/lib/systemd/system/%{name}.service
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d/
sed -e 's,@LOGDIR@,%{_localstatedir}/log/%{name},g;s,@BINDIR@,%{_bindir},g' \
    %{SOURCE4} > %{buildroot}%{_sysconfdir}/logrotate.d/%{name}.conf

mkdir -p %{buildroot}%{_localstatedir}/{lib,spool,log}/%{name}
mkdir -p %{buildroot}/run/%{name} %{buildroot}/run/lock/%{name}
mkdir -p %{buildroot}%{_sysconfdir}/%{name}.d


%check
patch -p0 < %{PATCH7}
sed -i -e 's,@BINDIR@,%{buildroot}%{_libexecdir}/%{name},' src/mailman/testing/testing.cfg
PYTHONPATH=`pwd`/src nose2 -v


%pre
getent group %{mmgroup} >/dev/null || \
    groupadd -g %{mmgroupid} %{mmgroup} >/dev/null
getent passwd %{mmuser} >/dev/null || \
    useradd -r -u %{mmuserid} -g %{mmgroupid} -d %{_localstatedir}/lib/%{name} -s /sbin/nologin \
        -c "Mailman, the mailing-list manager" %{mmuser} >/dev/null
exit 0

%post
%systemd_post %{name}.service

%preun
%systemd_preun %{name}.service

%postun
%systemd_postun_with_restart %{name}.service


%files
%doc README.rst
%{_bindir}/%{name}
%{_libexecdir}/%{name}
%{python_sitelib}/%{pypi_name}
%{python_sitelib}/%{pypi_name}-*-py?.?.egg-info
%{_prefix}/lib/systemd/system/%{name}.service
%{_prefix}/lib/tmpfiles.d/%{name}.conf
%config(noreplace) %{_sysconfdir}/mailman.cfg
%dir %{_sysconfdir}/%{name}.d
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}.conf
%dir %attr(755,mailman,mailman) %{_localstatedir}/lib/%{name}
%dir %attr(755,mailman,mailman) %{_localstatedir}/spool/%{name}
%dir %attr(755,mailman,mailman) %{_localstatedir}/log/%{name}
%dir %attr(755,mailman,mailman) /run/%{name}
%dir %attr(755,mailman,mailman) /run/lock/%{name}


%changelog
* Thu Aug 29 2013 Aurelien Bompard <abompard@fedoraproject.org> - 3.0.0-0.6.bzr7218
- update to BZR snapshot (rev7218)

* Wed Aug 28 2013 Aurelien Bompard <abompard@fedoraproject.org> - 3.0.0-0.6.bzr7217
- update to BZR snapshot (rev7217)
- drop patch 0
- rename to mailman3 and make it parallel-installable with Mailman 2

* Wed Jul 24 2013 Aurelien Bompard <abompard@fedoraproject.org> - 3:3.0.0-0.6
- update to BZR snapshot (rev7215)
- drop patch 1

* Thu Mar 07 2013 Aurelien Bompard <abompard@fedoraproject.org> - 3:3.0.0-0.2.b3
- update to beta3
- add a systemd service and a default config file

* Wed Nov 28 2012 Aurelien Bompard <abompard@fedoraproject.org> - 3.0.0b2-1
- Initial package.
